@@ -17,102 +17,6 @@
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-*
-* Tag: $Name:  $
-*
-* Change log:
-*
-* $Log: dvgrab.cc,v $
-* Revision 1.25  2004/11/30 04:46:22  ddennedy
-* make duration more accurate, particularly 1 frame
-*
-* Revision 1.24  2004/07/22 02:29:06  ddennedy
-* remove bogus patch suffix on version
-*
-* Revision 1.23  2004/07/22 02:25:14  ddennedy
-* added --timesys option
-*
-* Revision 1.22  2004/07/14 03:24:20  ddennedy
-* added dv1394.h, fixed gcc 3.4 compilation and cleanup statics in ieee1394io, applied patchfor csize and cmincutsize options
-*
-*
-* Revision 1.21patch-3 2004/06/12 pmdumuid
-* add more splitting options (--csize & --csizecutmin) -- improved over patch "1.21patch-3 2004/06/11 pmdumuid"
-* Cleaned up a bit of formatting of the --help info
-*
-* Revision 1.21  2004/01/14 13:46:29  ddennedy
-* bugfix --every
-*
-* Revision 1.20  2003/12/30 05:47:24  ddennedy
-* bugfixes to autosplit, added timecode discontinuity to autosplit, fix setting of a good sample frame, revert OpenDML warning on dv1
-*
-* Revision 1.19  2003/12/27 20:07:22  schirmacher
-* bugfixes for DVGRAB-17, DVGRAB-19 and partially DVGRAB-16
-* (capture aborted for files larger than 1008 MByte)
-*
-* Revision 1.18  2003/11/25 06:21:22  ddennedy
-* make work in camera mode
-*
-* Revision 1.17  2003/11/16 22:36:49  ddennedy
-* run make pretty and remove deprecated strstream
-*
-* Revision 1.16  2003/11/16 22:06:20  ddennedy
-* allow interruption during initialization of start capture
-*
-* Revision 1.15  2003/10/14 05:59:36  ddennedy
-* bugfixes, --guid, and --noavc improvements
-*
-* Revision 1.14  2003/10/14 05:52:05  ddennedy
-* bugfixes, --guid, and --noavc improvements
-*
-* Revision 1.13  2003/10/09 19:42:02  ddennedy
-* ring terminal bell on frame drop
-*
-* Revision 1.12  2003/10/09 19:06:18  ddennedy
-* fix --opendml default
-*
-* Revision 1.11  2003/10/09 19:02:48  ddennedy
-* little fix on smil time doc, set default --frames to 0, documemt --frames 0 = ulimited
-*
-* Revision 1.10  2003/10/08 21:31:12  ddennedy
-* added --noavc option
-*
-* Revision 1.9  2003/10/08 04:23:26  ddennedy
-* make duration work with non-file capture
-*
-* Revision 1.8  2003/09/27 01:30:54  ddennedy
-* require --stdin to read from pipe
-*
-* Revision 1.7  2003/09/26 18:33:32  ddennedy
-* rework avc discovery and argv parsing order
-*
-* Revision 1.6  2003/09/26 14:11:38  ddennedy
-* rawdv on stdin, smil-based duration
-*
-* Revision 1.5  2003/09/17 22:10:12  ddennedy
-* major new features: namely interactive mode and AV/C control
-*
-* Revision 1.4  2003/04/21 17:14:00  ddennedy
-* result return on WriteFrame methods, auto set OpenDML where needed
-*
-* Revision 1.3  2003/02/23 02:02:12  ddennedy
-* added raw to stdout, updated docs
-*
-* Revision 1.2  2003/02/07 04:25:15  ddennedy
-* bugfix processing jpeg options
-*
-* Revision 1.4  2002/03/25 21:34:25  arne
-* Support for large (64 bit) files mostly completed
-*
-* Revision 1.3  2002/03/10 21:28:29  arne
-* release 1.1b1, 64 bit support for type 1 avis
-*
-* Revision 1.2  2002/03/04 19:22:43  arne
-* updated to latest Kino avi code
-*
-* Revision 1.1.1.1  2002/03/03 19:08:08  arne
-* import of version 1.01
-*
 */
 
 
@@ -227,9 +131,8 @@ DVgrab::~DVgrab()
 	m_reader_active = false;
 	if ( m_reader )
 	{
-		m_reader->TriggerAction( );
-		pthread_join( capture_thread, NULL );
 		m_reader->StopThread();
+		pthread_join( capture_thread, NULL );
 		delete m_reader;
 	}
 	if ( m_avc )
@@ -502,13 +405,9 @@ void DVgrab::getargs( int argc, char *argv[] )
 			fprintf( stderr, "  --channel number  iso channel number for listening (default %d).\n", m_channel );
 			fprintf( stderr, "  --buffers number  the number of internal frames to buffer (default %d).\n", m_buffers );
 			fprintf( stderr, "  --stdin           read raw DV from stdin pipe (default uses raw1394.)\n" );
-#ifdef HAVE_LIBDV_DV1394_H
-
 			fprintf( stderr, "  --dv1394 [device] use the dv1394 device named device (default uses raw1394.)\n" );
 			fprintf( stderr, "                      device specification is optional if you follow the dv1394\n" );
 			fprintf( stderr, "                      devfs naming convention: /dev/ieee1394/dv/hostX/....\n" );
-#endif
-
 			fprintf( stderr, "  --help            display this help and exit.\n" );
 			fprintf( stderr, "  --version         display version information and exit.\n" );
 			fprintf( stderr, "\nCheck out the dvgrab website for the latest version, news and other software:\n" );
@@ -647,7 +546,13 @@ void DVgrab::stopCapture()
 			TimeCode timeCode;
 			struct tm recDate;
 			m_frame->GetTimeCode( timeCode );
-			m_frame->GetRecordingDate( recDate );
+			if ( ! m_frame->GetRecordingDate( recDate ) )
+			{
+				// If the month is invalid, then report system date/time
+				time_t timesys;
+				time( &timesys );
+				localtime_r( &timesys, &recDate );
+			}
 			sendEvent( "\"%s\": %8.2f MB %d frames timecode %2.2d:%2.2d:%2.2d.%2.2d date %4.4d.%2.2d.%2.2d %2.2d:%2.2d:%2.2d",
 			           filename.c_str(), size, frames,
 			           timeCode.hour, timeCode.min, timeCode.sec, timeCode.frame,
@@ -703,10 +608,17 @@ void DVgrab::captureThreadRun()
 		if ( m_frame != NULL )
 		{
 			m_frame->GetTimeCode( timeCode );
+			m_frame->GetRecordingDate( recDate );
+			if ( ! m_frame->GetRecordingDate( recDate ) )
+			{
+				// If the month is invalid, then report system date/time
+				time_t timesys;
+				time( &timesys );
+				localtime_r( &timesys, &recDate );
+			}
 			
 			if ( dropped > 0 )
 			{
-				m_frame->GetRecordingDate( recDate );
 				m_dropped_frames += dropped;
 				sendEvent( "\a\"%s\": buffer underrun near: timecode %2.2d:%2.2d:%2.2d.%2.2d date %4.4d.%2.2d.%2.2d %2.2d:%2.2d:%2.2d",
 				           m_writer ? m_writer->GetFileName().c_str() : "stdout",
@@ -717,7 +629,6 @@ void DVgrab::captureThreadRun()
 			}
 			if ( m_frame->IsComplete() == false )
 			{
-				m_frame->GetRecordingDate( recDate );
 				m_dropped_frames++;
 				sendEvent( "\a\"%s\": frame dropped: timecode %2.2d:%2.2d:%2.2d.%2.2d date %4.4d.%2.2d.%2.2d %2.2d:%2.2d:%2.2d",
 				           m_writer ? m_writer->GetFileName().c_str() : "stdout",
@@ -757,7 +668,6 @@ void DVgrab::captureThreadRun()
 						{
 							m_writer->CollectionCounterUpdate();
 							m_writer->Close();
-							m_frame->GetRecordingDate( recDate );
 							sendEvent( "\"%s\": %8.2f MB %d frames timecode %2.2d:%2.2d:%2.2d.%2.2d date %4.4d.%2.2d.%2.2d %2.2d:%2.2d:%2.2d",
 									   m_writer->GetFileName().c_str(), size, m_writer->GetFramesWritten(),
 									   timeCode.hour, timeCode.min, timeCode.sec, timeCode.frame,
@@ -784,7 +694,6 @@ void DVgrab::captureThreadRun()
 						// The file will be closed if max size or frames are exceeded
 						if ( !m_writer->FileIsOpen() )
 						{
-							m_frame->GetRecordingDate( recDate );
 							sendEvent( "\"%s\": %8.2f MB %d frames timecode %2.2d:%2.2d:%2.2d.%2.2d date %4.4d.%2.2d.%2.2d %2.2d:%2.2d:%2.2d",
 									   m_writer->GetFileName().c_str(), size, m_writer->GetFramesWritten(),
 									   timeCode.hour, timeCode.min, timeCode.sec, timeCode.frame,
