@@ -321,7 +321,7 @@ bool FileHandler::WriteFrame( Frame& frame )
 			}
 			else
 			{
-				recDate = "0000.00.00_00-00-00";
+				goto TimeSys;
 			}
 			sb2 << GetBaseName() << recDate << GetExtension();
 			filename = sb2.str();
@@ -329,6 +329,7 @@ bool FileHandler::WriteFrame( Frame& frame )
 		}
 		else if ( GetTimeSys() )
 		{
+TimeSys:
 			ostringstream	sb, sb2;
 			time_t timesys;
 			struct tm date;
