@@ -3,6 +3,7 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <errno.h>
+#include <string.h>
 #include <libavc1394/avc1394.h>
 #include <libavc1394/rom1394.h>
 
@@ -78,7 +79,6 @@ raw1394handle_t raw1394_open( int port )
 		exit( EXIT_FAILURE );
 	}
 
-	raw1394_set_userdata( handle, ( void* ) port );
 	return handle;
 }
 
